@@ -1,5 +1,11 @@
+import sys
 from dataclasses import dataclass
-from typing import List, Optional, TypedDict
+from typing import List, Optional
+
+if sys.version_info >= (3, 8):
+    from typing import TypedDict
+else:
+    from typing_extensions import TypedDict
 
 
 @dataclass
